daily_mean: Production of daily means from hourly temperature series
Description
The function works on a list of hourly temperature
series. The hourly list is the output of the
interpolation function Th_int, called iteratively
to produce a list where each component represents one
interpolated series.
Usage
daily_mean(hourly_list, series_names = NULL)
Arguments
hourly_list
the list of hourly temperatures
series_names
names of the serie to be averaged (if
NULL (default): all series)
Value
A list of daily averaged series
References
Eccel, E., 2010: What we can ask to hourly temperature
recording. Part II: hourly interpolation of temperatures
for climatology and modelling. Italian Journal of
Agrometeorology XV(2):45-50
Eccel, E., 2010: What we can ask to hourly temperature
recording. Part I: statistical vs. meteorological meaning
of minimum temperature. Italian Journal of
Agrometeorology XV(2):41-43.
data(Trentino_hourly_T)
# generates daily means for series T0001 and T0129:Tm_list <- daily_mean(hourly_list = Th_int_list, series_names = c("T0001", "T0129"))